Summary:        BPF Compiler Collection (BCC)
Name:           bcc
Version:        0.29.1
Release:        5%{?dist}
License:        ASL 2.0
URL:            https://github.com/iovisor/bcc
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

Patch0001: CVE-2024-2314-0001-clang-check-header-ownership-4928.patch
Patch0002: CVE-2024-2314-0002-clang-Fix-file_exists_and_ownedby-return-value.patch

ExclusiveArch:  x86_64 aarch64 loongarch64

BuildRequires:  bison cmake >= 2.8.7 llvm-devel clang-devel python3-devel
BuildRequires:  flex libxml2-devel ncurses-devel
BuildRequires:  libbpf-devel >= 0.8.0-1, libbpf-static >= 0.8.0-1
BuildRequires:  elfutils-libelf-devel pkgconfig(luajit) python3-setuptools

Requires:       libbpf >= 0.8.0-1
Requires:       tar
Recommends:     kernel-devel
Recommends:     %{name}-tools = %{version}-%{release}

%description
BCC is a toolkit for creating efficient kernel tracing and manipulation
programs, and includes several useful tools and examples. It makes use of
extended BPF (Berkeley Packet Filters), formally known as eBPF, a new feature
that was first added to Linux 3.15. BCC makes BPF programs easier to write,
with kernel instrumentation in C (and includes a C wrapper around LLVM), and
front-ends in Python and lua. It is suited for many tasks, including
performance analysis and network traffic control.


%package devel
Summary:        Shared library for BPF Compiler Collection (BCC)
Requires:       %{name} = %{version}-%{release}
Suggests:       elfutils-debuginfod-client

%description devel
The %{name}-devel package contains libraries and header files for developing
application that use BPF Compiler Collection (BCC).

%package lua
Summary:        Standalone tool to run BCC tracers written in Lua
Requires:       %{name} = %{version}-%{release}

%description lua
Standalone tool to run BCC tracers written in Lua

%package doc
Summary:        Examples for BPF Compiler Collection (BCC)
Recommends:     python3-%{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
Examples for BPF Compiler Collection (BCC)


%package -n python3-%{name}
Summary:        Python3 bindings for BPF Compiler Collection (BCC)
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description -n python3-%{name}
Python3 bindings for BPF Compiler Collection (BCC)

%package tools
Summary:        Command line tools for BPF Compiler Collection (BCC)
Requires:       bcc = %{version}-%{release}
Requires:       python3-%{name} = %{version}-%{release}
Requires:       python3-netaddr

%description tools
Command line tools for BPF Compiler Collection (BCC)

%prep
%autosetup -p1


%build
export CXXFLAGS="-lstdc++"
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DREVISION_LAST=%{version} -DREVISION=%{version} -DPYTHON_CMD=python3 \
       -DCMAKE_USE_LIBBPF_PACKAGE:BOOL=TRUE \
       -DENABLE_LLVM_SHARED=1
%cmake_build

%install
%cmake_install

find %{buildroot}%{_datadir}/%{name}/{tools,examples} -type f -exec \
  sed -i -e '1s=^#!/usr/bin/python\([0-9.]\+\)\?$=#!%{__python3}=' \
         -e '1s=^#!/usr/bin/env python\([0-9.]\+\)\?$=#!%{__python3}=' \
         -e '1s=^#!/usr/bin/env bcc-lua$=#!/usr/bin/bcc-lua=' {} \;

mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_datadir}/%{name}/man/* %{buildroot}%{_mandir}/

for manpage in `find %{buildroot}%{_mandir} -name "*.gz"`; do
  tname=$(basename $manpage)
  rename $tname %{name}-$tname $manpage
done

rm -rf %{buildroot}%{_datadir}/%{name}/tools/old/
rm -f %{buildroot}%{_libdir}/lib%{name}*.{a,la}

%files
%license LICENSE.txt
%doc README.md
%{_libdir}/lib%{name}.so.*
%{_libdir}/libbcc_bpf.so.*

%files devel
%{_libdir}/lib%{name}.so
%{_libdir}/libbcc_bpf.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_includedir}/%{name}/

%files lua
%{_bindir}/bcc-lua

%files -n python3-%{name}
%{python3_sitelib}/%{name}*

%files doc
%{_datadir}/%{name}/examples/*

%files tools
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/tools/
%{_datadir}/%{name}/introspection/
%{_mandir}/man8/*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.29.1-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.29.1-4
- Rebuilt for loongarch release

* Thu May 30 2024 Pengda Dou <doupengda@loongson.cn> - 0.29.1-3
- [Type] other
- [DESC] add loongarch64 to ExclusiveArch

* Thu Mar 14 2024 Chunsheng Luo <luffyluo@tencent.com> - 0.29.1-2
- Fix CVE-2024-2314

* Fri Jan 19 2024 Upgrade Robot <upbot@opencloudos.org> - 0.29.1-1
- Upgrade to version 0.29.1

* Wed Jan 17 2024 Rebuild Robot <rebot@opencloudos.org> - 0.28.0-5
- Rebuilt for elfutils

* Thu Dec 21 2023 Rebuild Robot <rebot@opencloudos.org> - 0.28.0-4
- Rebuilt for clang

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.28.0-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.28.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 17 2023 kianli <kianli@tencent.com> - 0.28.0-1
- Upgrade to 0.28.0

* Tue May 09 2023 cunshunxia <cunshunxia@tencent.com> - 0.25.0-4
- rename manpage because of conflicts with postfix's trace.

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.25.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.25.0-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Nov 25 2022 cunshunxia <cunshunxia@tencent.com> - 0.25.0-1
- initial build
